@@ -1,9 +1,7 @@
 package Yeb;
-BEGIN {
-  $Yeb::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: A simple structure for Web::Simple applications
-$Yeb::VERSION = '0.103';
+$Yeb::VERSION = '0.104';
 use strict;
 use warnings;
 
@@ -29,7 +27,7 @@ Yeb - A simple structure for Web::Simple applications
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
