@@ -1,15 +1,13 @@
 package Yeb::Application;
-BEGIN {
-  $Yeb::Application::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Main Meta Class for a Yeb Application
-$Yeb::Application::VERSION = '0.103';
+$Yeb::Application::VERSION = '0.104';
 use Moo;
 use Package::Stash;
 use Import::Into;
 use Yeb::Context;
 use Yeb::Class;
-use Class::Load ':all';
+use Module::Runtime qw( use_module );
 use Path::Tiny qw( path );
 use Plack::Middleware::Debug;
 use List::Util qw( reduce );
@@ -209,7 +207,7 @@ sub class_loader {
 	} else {
 		$class = $self->class.'::'.$class;
 	}
-	load_class($class) unless is_class_loaded($class);
+	use_module($class);
 	return $class;
 }
 
@@ -251,7 +249,7 @@ sub add_plugin {
 	} else {
 		$class = 'Yeb::Plugin::'.$plugin;
 	}
-	load_class($class);
+	use_module($class);
 	my $obj = $class->new( app => $self, class => $self->y($source) , %args );
 	push @{$self->plugins}, $obj;
 }
@@ -378,7 +376,7 @@ Yeb::Application - Main Meta Class for a Yeb Application
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SUPPORT
 
