@@ -1,13 +1,9 @@
 package Yeb::Class;
-BEGIN {
-  $Yeb::Class::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Meta Class for all Yeb application classes
-$Yeb::Class::VERSION = '0.103';
+$Yeb::Class::VERSION = '0.104';
 use Moo;
 use Package::Stash;
-use Class::Load ':all';
-use Path::Tiny qw( path );
 
 has app => (
 	is => 'ro',
@@ -114,7 +110,7 @@ Yeb::Class - Meta Class for all Yeb application classes
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SUPPORT
 
