@@ -1,9 +1,7 @@
 package Yeb::Context;
-BEGIN {
-  $Yeb::Context::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Storage for context of request
-$Yeb::Context::VERSION = '0.103';
+$Yeb::Context::VERSION = '0.104';
 use Moo;
 use Plack::Request;
 use URI;
@@ -96,7 +94,7 @@ Yeb::Context - Storage for context of request
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SUPPORT
 
