@@ -1,9 +1,7 @@
 package Yeb::Plugin::Static;
-BEGIN {
-  $Yeb::Plugin::Static::AUTHORITY = 'cpan:GETTY';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Yeb Plugin for Plack::Middleware::Static
-$Yeb::Plugin::Static::VERSION = '0.103';
+$Yeb::Plugin::Static::VERSION = '0.104';
 use Moo;
 use Path::Tiny qw( path );
 use Plack::Middleware::Static;
@@ -80,7 +78,7 @@ Yeb::Plugin::Static - Yeb Plugin for Plack::Middleware::Static
 
 =head1 VERSION
 
-version 0.103
+version 0.104
 
 =head1 SYNOPSIS
 
