@@ -10,4 +10,8 @@ r "/a" => sub {
 	text "other a";
 };
 
+r "/other" => sub {
+	text "other and ".ex('other_app');
+};
+
 1;
\ No newline at end of file
